==> org.apache.sling.api-2.27.2-sources.jar: org/apache/sling/api/request/builder/impl/RequestParameterMapImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.api.request.builder.impl;

import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.sling.api.request.RequestParameter;
import org.apache.sling.api.request.RequestParameterMap;
import org.jetbrains.annotations.NotNull;

/**
 * Implementation of {@link RequestParameterMap}.
 */
public class RequestParameterMapImpl extends LinkedHashMap<String, RequestParameter[]>
    implements RequestParameterMap {
    
    public RequestParameterMapImpl(@NotNull final Map<String, String[]> params) {
        for(final Map.Entry<String, String[]> entry : params.entrySet()) {
            final RequestParameter[] values = new RequestParameter[entry.getValue().length];
            int index = 0;
            for(final String v : entry.getValue()) {
                values[index] = new RequestParameterImpl(entry.getKey(), v);
                index++;
            }
            this.put(entry.getKey(), values);
        }
    }

    @Override
    public RequestParameter getValue(final String name) {
        RequestParameter[] params = getValues(name);
        return (params != null && params.length > 0) ? params[0] : null;
    }

    @Override
    public RequestParameter[] getValues(final String name) {
        return this.get(name);
    }
}

==> org.apache.sling.api-3.0.2-sources.jar: org/apache/sling/api/request/builder/impl/RequestParameterMapImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.api.request.builder.impl;

import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.sling.api.request.RequestParameter;
import org.apache.sling.api.request.RequestParameterMap;
import org.jetbrains.annotations.NotNull;

/**
 * Implementation of {@link RequestParameterMap}.
 */
public class RequestParameterMapImpl extends LinkedHashMap<String, RequestParameter[]> implements RequestParameterMap {

    public RequestParameterMapImpl(@NotNull final Map<String, String[]> params) {
        for (final Map.Entry<String, String[]> entry : params.entrySet()) {
            final RequestParameter[] values = new RequestParameter[entry.getValue().length];
            int index = 0;
            for (final String v : entry.getValue()) {
                values[index] = new RequestParameterImpl(entry.getKey(), v);
                index++;
            }
            this.put(entry.getKey(), values);
        }
    }

    @Override
    public RequestParameter getValue(final String name) {
        RequestParameter[] params = getValues(name);
        return (params != null && params.length > 0) ? params[0] : null;
    }

    @Override
    public RequestParameter[] getValues(final String name) {
        return this.get(name);
    }
}
